mutationtools
=============

.. automodule:: abjad.tools.mutationtools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.mutationtools.AttributeInspectionAgent.AttributeInspectionAgent.AttributeInspectionAgent
      ~abjad.tools.mutationtools.ScoreMutationAgent.ScoreMutationAgent.ScoreMutationAgent

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.mutationtools.mutate.mutate
